import { ɵɵdefineInjectable, ɵɵinject, Injectable, Optional, Component, NgModule } from '@angular/core';
import { tap } from 'rxjs/operators';

var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["DEBUG"] = 0] = "DEBUG";
    LogLevel[LogLevel["INFO"] = 1] = "INFO";
    LogLevel[LogLevel["WARNING"] = 2] = "WARNING";
    LogLevel[LogLevel["ERROR"] = 3] = "ERROR";
})(LogLevel || (LogLevel = {}));
class LoggerConfig {
    constructor() {
        this.showTime = true;
        this.logLevel = LogLevel.DEBUG;
        this.showEmoji = true;
        this.showLabel = true;
        this.disableLogs = false;
        this.levelColor = {};
        this.levelEmoji = {};
    }
}
const DEFAULT_LEVEL_COLORS = {
    [LogLevel.DEBUG]: 'black',
    [LogLevel.INFO]: 'steelblue',
    [LogLevel.WARNING]: 'orange',
    [LogLevel.ERROR]: 'red'
};
class SampleLibService {
    constructor(config) {
        this.levelPrefix = {};
        this.getStyles = (level) => `color:white;
                        background-color:${this.config.levelColor[level] || DEFAULT_LEVEL_COLORS[level]};
                        padding: 0px 2px;
                        border-radius: 2px`;
        this.debugOperator = (message, logLevel = LogLevel.DEBUG) => tap(data => {
            this.log(logLevel, message || '', data);
        });
        let DEFAULT_CONFIG = new LoggerConfig();
        this.config = Object.assign(Object.assign({}, DEFAULT_CONFIG), config);
        this.setPrefix();
    }
    setPrefix() {
        if (this.config.disableLogs) {
            return;
        }
        for (const key in LogLevel) {
            if (!isNaN(Number(key))) {
                let prefix = '';
                if (this.config.showLabel) {
                    prefix += LogLevel[key];
                }
                this.levelPrefix[key] = prefix;
            }
        }
    }
    log(logLevel, ...args) {
        if (this.config.disableLogs || (logLevel < this.config.logLevel)) {
            return;
        }
        console.log(`%c${this.levelPrefix[logLevel]}${this.config.showTime ? `> ${new Date().toLocaleString()}` : ''}`, this.getStyles(logLevel), ...args);
    }
    info(...args) {
        this.log(LogLevel.INFO, ...args);
    }
    debug(...args) {
        this.log(LogLevel.DEBUG, ...args);
    }
    warn(...args) {
        this.log(LogLevel.WARNING, ...args);
    }
    error(...args) {
        this.log(LogLevel.ERROR, ...args);
    }
    header(title, config = {}) {
        const styles = `font-size: ${config.fontSize || 20}px; color:${config.color || 'steelblue'};   text-shadow: #ddd 2px 2px 2px`;
        console.log(`%c${title}`, styles);
    }
}
SampleLibService.ɵprov = ɵɵdefineInjectable({ factory: function SampleLibService_Factory() { return new SampleLibService(ɵɵinject(LoggerConfig, 8)); }, token: SampleLibService, providedIn: "root" });
SampleLibService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
SampleLibService.ctorParameters = () => [
    { type: LoggerConfig, decorators: [{ type: Optional }] }
];

class SampleLibComponent {
    constructor() { }
    ngOnInit() {
    }
}
SampleLibComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-sample-lib',
                template: `
    <p>
      sample-lib works!
    </p>
  `
            },] }
];
SampleLibComponent.ctorParameters = () => [];

class SampleLibModule {
    static forRoot(config) {
        return {
            ngModule: SampleLibModule,
            providers: [
                { provide: LoggerConfig, useValue: config || {} }
            ]
        };
    }
}
SampleLibModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SampleLibComponent],
                imports: [],
                exports: [SampleLibComponent]
            },] }
];

/*
 * Public API Surface of sample-lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { LogLevel, LoggerConfig, SampleLibComponent, SampleLibModule, SampleLibService };
//# sourceMappingURL=ngdevelop-sample-lib.js.map
